@@ -62,7 +62,6 @@ Logging options
   -u --url-only     Display generated URL after upload directly on stdout, implies --quiet
   --batch           Display generated URL after upload with platform information for easier parsing. Implies --quiet
                     Be careful --batch and --url-only are mutually exclusives.
-  --debug           (Deprecated) Alias for --log=debug. Ignored if --log is set
 
 Strict options:
   Strict options allow you to force some option to be present when uploading a video. It's useful to be sure you do not
@@ -125,7 +124,7 @@ except ImportError:
                   'see https://github.com/halst/schema\n')
     exit(1)
 
-VERSION = "prismedia v0.12.0"
+VERSION = "prismedia v0.12.1"
 
 VALID_PRIVACY_STATUSES = ('public', 'private', 'unlisted')
 VALID_CATEGORIES = (
@@ -228,19 +227,20 @@ def configureLogs(options):
     if options.get('--batch') or options.get('--url-only'):
         options['--quiet'] = True
 
-    if options.get('--quiet'):
-        # We need to set both log level in the same time
-        logger.setLevel(50)
-        ch.setLevel(50)
-    elif options.get('--log'):
-        numeric_level = getattr(logging, options["--log"], None)
-        # We need to set both log level in the same time
-        logger.setLevel(numeric_level)
-        ch.setLevel(numeric_level)
-    elif options.get('--debug'):
-        logger.warning("DEPRECATION: --debug is deprecated, please use --log=debug instead")
-        logger.setLevel(10)
-        ch.setLevel(10)
+    for handler in logger.handlers or logger.parent.handlers:
+        if options.get('--quiet'):
+            # We need to set both log level in the same time
+            logger.setLevel(50)
+            handler.setLevel(50)
+        elif options.get('--log'):
+            numeric_level = getattr(logging, options["--log"], None)
+            # We need to set both log level in the same time
+            logger.setLevel(numeric_level)
+            handler.setLevel(numeric_level)
+        elif options.get('--debug'):
+            # Deprecated,
+            logger.setLevel(10)
+            handler.setLevel(10)
 
 
 def configureStdoutLogs():
